#### Higher Locomotor Costs of Pregnancy in Viviparous Compared to Oviparous Common Lizards (Zootoca Vivipara) ####
### Author: Robbie Hussain
### Contact: robert.hussain@stcatz.ox.ac.uk
### Date: 25/07/24 (Includes data clean up and summary statistics)

#First set working directory to wherever you have saved your files.

#Libraries required
library(ggplot2)
library(gridExtra)
library(lme4)
library(lmerTest)
library(MuMIn)
library(psych)
library(ggeffects)
library("magrittr")
library(multcomp)
library(emmeans)
library(ggsignif)
library(ggpubr)
library(grid)
library(lattice)
library(dplyr)
library(tidyverse)
library(arm)

#Load in the Data
run_data <- read.csv("lizard_running_data_modified.csv", header = TRUE)
#making the repeat number a factor
run_data$repeat_m<-as.factor(run_data$repeat_m)

#subsets of the data
all_laid<-subset(run_data, pregnancy_status=="laid")
ROM_laid<-subset(all_laid, repeat_m=="1")
all_pregnant<-subset(run_data, pregnancy_status=="pregnant")
ROM_pregnant<-subset(all_pregnant, repeat_m=="1")

#### Data Exploration and Clean-Up ####
# Count the number of rows with at least one NA
sum(rowSums(is.na(run_data)) > 0) #149
#this is why some of the models have only 667 observations (816-149)
clean_data <- na.omit(run_data) #667 columns
sum(rowSums(is.na(clean_data)) > 0) #0 NA's

#looking at how many lizards of each parity mode we have in full dataset
all_unique_field_ids <- unique(run_data$field_id)
all_unique_field_ids
# Extract the associated parity mode for unique field IDs
all_parity_modes <- run_data$parity_mode[match(all_unique_field_ids, run_data$field_id)]

# Create a dataframe containing unique field IDs and their associated categorical variable
all_lizards <- data.frame(
  field_id = all_unique_field_ids,
  parity_modes = all_parity_modes
)
#count how many ovi, vivi and hybrids we have in dataset
table(all_lizards$parity_modes) #45 ovi, 47 vivi and 14 hybrids as we expect

#looking at how many lizards of each parity mode we have in cleaned dataset
clean_unique_field_ids <- unique(clean_data$field_id)
clean_unique_field_ids
# Extract the associated parity mode for unique field IDs
clean_parity_modes <- clean_data$parity_mode[match(clean_unique_field_ids, clean_data$field_id)]

# Create a dataframe containing unique field IDs and their associated categorical variable
clean_lizards <- data.frame(
  field_id = clean_unique_field_ids,
  parity_modes = clean_parity_modes
)
#count how many ovi, vivi and hybrids we have in dataset
table(clean_lizards$parity_modes) #36 ovi, 41 vivi and 8 hybrids as we expect

#looking for lizard that is missing weight data
na_indices <- which(is.na(run_data$weight_end))
na_indices #775 and 776
run_data[775, ] #lizard HR_15_364 - viviparous, day 1
run_data[776, ] #lizard HR_15_364 - viviparous, day 2

#Pregnant ROM Data

sum(is.na(ROM_pregnant$ROM) > 0) #19 NAs
clean_ROM_data <- ROM_pregnant[!is.na(ROM_pregnant$ROM), ]
sum(rowSums(is.na(clean_ROM_data)) > 0) #1 NA, but not in ROM

#looking at how many lizards of each parity mode we have in ROM Pregnant dataset
ROM_unique_field_ids <- unique(clean_ROM_data$field_id)
ROM_unique_field_ids
# Extract the associated parity mode for unique field IDs
ROM_parity_modes <- clean_ROM_data$parity_mode[match(ROM_unique_field_ids, clean_ROM_data$field_id)]

# Create a dataframe containing unique field IDs and their associated categorical variable
ROM_lizards <- data.frame(
  field_id = ROM_unique_field_ids,
  parity_modes = ROM_parity_modes
)
#count how many ovi, vivi and hybrids we have in actual ROM dataset
table(ROM_lizards$parity_modes) #34 ovi, 41 vivi and 8 hybrids

# Clutch Size Data
sum(is.na(ROM_pregnant$N_laid) > 0) #1 NA
clean_CS_data <- ROM_pregnant[!is.na(ROM_pregnant$N_laid), ]
sum(rowSums(is.na(clean_CS_data)) > 0) #19 NAs, but not in N_laid

#looking at how many lizards of each parity mode we have in ROM Pregnant dataset
CS_unique_field_ids <- unique(clean_CS_data$field_id)
CS_unique_field_ids
# Extract the associated parity mode for unique field IDs
CS_parity_modes <- clean_CS_data$parity_mode[match(CS_unique_field_ids, clean_CS_data$field_id)]

# Create a dataframe containing unique field IDs and their associated categorical variable
CS_lizards <- data.frame(
  field_id = CS_unique_field_ids,
  parity_modes = CS_parity_modes
)
#count how many ovi, vivi and hybrids we have in actual ROM dataset
table(CS_lizards$parity_modes) #34 ovi, 41 vivi and 8 hybrids


##### Summary Statistics ####

### Average Speed Summary ###
vmean_summary <- run_data %>%
  group_by(parity_mode, pregnancy_status) %>%
  summarize(
    mean = mean(vmean, na.rm = TRUE),
    median = median(vmean, na.rm = TRUE),
    min = min(vmean, na.rm = TRUE),
    max = max(vmean, na.rm = TRUE),
    sd = sd(vmean, na.rm = TRUE)
  )
vmean_summary

#Maximum Speed Summary
vmax_summary <- run_data %>%
  group_by(parity_mode, pregnancy_status) %>%
  summarize(
    mean = mean(vmax, na.rm = TRUE),
    median = median(vmax, na.rm = TRUE),
    min = min(vmax, na.rm = TRUE),
    max = max(vmax, na.rm = TRUE),
    sd = sd(vmax, na.rm = TRUE)
  )
vmax_summary

### Average Distance Summary ###
distmean_summary <- run_data %>%
  group_by(parity_mode, pregnancy_status) %>%
  summarize(
    mean = mean(distmean, na.rm = TRUE),
    median = median(distmean, na.rm = TRUE),
    min = min(distmean, na.rm = TRUE),
    max = max(distmean, na.rm = TRUE),
    sd = sd(distmean, na.rm = TRUE)
  )
distmean_summary

#Maximum Distance Summary
distmax_summary <- run_data %>%
  group_by(parity_mode, pregnancy_status) %>%
  summarize(
    mean = mean(distmax, na.rm = TRUE),
    median = median(distmax, na.rm = TRUE),
    min = min(distmax, na.rm = TRUE),
    max = max(distmax, na.rm = TRUE),
    sd = sd(distmax, na.rm = TRUE)
  )
distmax_summary

#Weight summary
weight_summary <- run_data %>%
  group_by(parity_mode, pregnancy_status) %>%
  summarize(
    mean = mean(weight_end, na.rm = TRUE),
    median = median(weight_end, na.rm = TRUE),
    min = min(weight_end, na.rm = TRUE),
    max = max(weight_end, na.rm = TRUE),
    sd = sd(weight_end, na.rm = TRUE)
  )
weight_summary

#ROM Summary
ROM_summary <- ROM_pregnant %>%
  group_by(parity_mode) %>%
  summarize(
    mean_ROM = mean(ROM, na.rm = TRUE),
    median_ROM = median(ROM, na.rm = TRUE),
    min_ROM = min(ROM, na.rm = TRUE),
    max_ROM = max(ROM, na.rm = TRUE),
    sd_ROM = sd(ROM, na.rm = TRUE)
  )
ROM_summary

#Clutch Size Summary
CS_summary <- ROM_pregnant %>%
  group_by(parity_mode) %>%
  summarize(
    mean = mean(N_laid, na.rm = TRUE),
    median = median(N_laid, na.rm = TRUE),
    min = min(N_laid, na.rm = TRUE),
    max = max(N_laid, na.rm = TRUE),
    sd = sd(N_laid, na.rm = TRUE)
  )
CS_summary

############################ Model Selection ##############################

#### Model 1 - Average Speed ####

#most complex model - Average Speed
model0_vmean<-lmer(vmean~svl+ ROM*parity_mode +N_laid+ pregnancy_status*parity_mode + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE) #most complex model
summary(model0_vmean)

#Pregnancy status*parity mode interaction
model1_vmean<-lmer(vmean~svl+ ROM*parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model0_vmean,model1_vmean)
logLik(model0_vmean) #-2527.714 (df=18)
logLik(model1_vmean) #-2528.007 (df=16)
1-pchisq(0.586,2) #0.7460221 - non-significant, suggests removal of interaction
#drop parity mode x pregnancy status interaction

#ROM*parity_mode interaction
model2_vmean<-lmer(vmean~svl+ ROM+parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model1_vmean,model2_vmean) #0.05529 borderline keep interaction
logLik(model1_vmean) #-2528.007 (df=16)
logLik(model2_vmean) #-2530.903 (df=14)
1-pchisq(5.792,2) #0.05524375 borderline keep model 1 with ROM*parity_mode interaction
#retain ROM x parity mode interaction

#Tail length
model3_vmean<- lmer(vmean~svl+ ROM*parity_mode +N_laid+ pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model1_vmean,model3_vmean)
#p=0.9445 non-significant, drop tail length

#N_laid
model4_vmean<- lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model4_vmean) # -2528.702, df=14
anova(model3_vmean,model4_vmean)
#p=0.2394, non-significant, drop N_laid

#svl
model5_vmean<-lmer(vmean~ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model5_vmean) #-2540.523, df=13
anova(model4_vmean, model5_vmean)
#p<0.001, retain svl

#weight
model6_vmean<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model6_vmean) #-2552.129, df=13
anova(model4_vmean,model6_vmean) #doesn't work
logLik(model4_vmean) #-2528.702, df=14
1-pchisq(46.854,1) #p<0.0005, retain weight

#dropping repeat
model7_vmean<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end +(1|field_id), data=run_data, REML=FALSE)
anova(model4_vmean, model7_vmean) #p<0.005, retain repeat

#Final Model
vmean_model<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
vmean_model<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(vmean_model)
anova(vmean_model)
#residuals vs fitted plot
residuals_vmean <- residuals(vmean_model)
plot(fitted(vmean_model), residuals_vmean, 
     xlab = "Fitted values", ylab = "Residuals", 
     main = "Residuals vs Fitted Values")
abline(h = 0, col = "red")
# Normal Q-Q plot
qqnorm(residuals_vmean, main = "Normal Q-Q Plot")
qqline(residuals_vmean, col = "red")

#using LRTs to assess model terms
vmean_interactionless<-lmer(vmean~svl +ROM +parity_mode +pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(vmean_model,vmean_interactionless) #2xLL = 7.36, df=2, p=0.02522
logLik(vmean_interactionless) #-2532.382, df=12
logLik(vmean_model) #-2528.834, df=14
1-pchisq(7.36,2)
vmean_weightless<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(vmean_weightless) #-2552.129, df=13
logLik(vmean_model) #-2528.702, df=14
1-pchisq(46.854, 1) #2xLL=46.854, df=1, p<0.005
vmean_pregnantless<-lmer(vmean~svl+ ROM*parity_mode + weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(vmean_model,vmean_pregnantless) #2xLL=14.944, df=1, p<0.005
logLik(vmean_pregnantless) #-2536.174, df=13
logLik(vmean_model) #-2528.702, df=14
1-pchisq(14.944,1)
vmean_repeatless<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end +(1|field_id), data=run_data, REML=FALSE)
anova(vmean_model, vmean_repeatless) #2xLL=14.944 , df=3, p<0.005
logLik(vmean_repeatless) #-2536.174, df=11
vmean_lengthless<-lmer(vmean~ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(vmean_model,vmean_lengthless) #2xLL=23.642, df=1, p<0.005
logLik(vmean_lengthless) #-2540.523, df=13

#### Model 2 - Maximum Speed ####

#most complex model - Maximum Speed
model0_vmax<-lmer(vmax~svl+ ROM*parity_mode +N_laid+ pregnancy_status*parity_mode + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE) #most complex model
summary(model0_vmax)


#Pregnancy status x parity mode interaction
model1_vmax<-lmer(vmax~svl+ ROM*parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model0_vmax,model1_vmax)#p=0.983 - non-significant, suggests removal of interaction
#drop parity mode x pregnancy status interaction

#ROM*parity_mode interaction
model2_vmax<-lmer(vmax~svl+ ROM+parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model1_vmax,model2_vmax) #0.07298 indicates dropping - but will retain for the moment
#retain ROM x parity mode interaction

#Tail length
model3_vmax<- lmer(vmax~svl+ ROM*parity_mode +N_laid+ pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model1_vmax,model3_vmax)#p=0.9124 non-significant, drop tail length

#N_laid
model4_vmax<- lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model4_vmax) # -2702.985, df=14
anova(model3_vmax,model4_vmax)
#p=0.2642, non-significant, drop N_laid

#svl
model5_vmax<-lmer(vmax~ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model5_vmax) #-2712.179, df=13
anova(model4_vmax, model5_vmax) #p<0.005, retain svl

#weight
model6_vmax<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model6_vmax) #-2722.48, df=13
anova(model4_vmax,model6_vmax) #doesn't work
logLik(model4_vmax) #-2702.985, df=14
1-pchisq(38.99,1) #p<0.0005, retain weight

#repeat
model7_vmax<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end +(1|field_id), data=run_data, REML=FALSE)
anova(model4_vmax, model7_vmax) #p<0.005, retain repeat

#Final Model
vmax_model<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
vmax_model<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(vmax_model)
anova(vmax_model)

#using LRTs to assess model terms - remember to use REML=FALSE of final model
vmax_interactionless<-lmer(vmax~svl +ROM +parity_mode +pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(vmax_model,vmax_interactionless) #2xLL = 6.284, df=2, p=0.04321
logLik(vmax_interactionless) #-2706.127, df=12
logLik(vmax_model) #-2702.985, df=14
1-pchisq(6.284,2)
vmax_weightless<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(vmax_weightless) #-2722.48, df=13
logLik(vmax_model) #-2702.985, df=14
1-pchisq(38.99, 1) #2xLL=38.99, df=1, p<0.005
vmax_pregnantless<-lmer(vmax~svl+ ROM*parity_mode + weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(vmax_model,vmax_pregnantless) #2xLL=12.596, df=1, p<0.005
logLik(vmax_pregnantless) #-2709.283, df=13
logLik(vmax_model) #-2702.985, df=14
1-pchisq(12.596,1)
vmax_repeatless<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end +(1|field_id), data=run_data, REML=FALSE)
anova(vmax_model, vmax_repeatless) #2xLL=9.444 , df=3, p<0.005
logLik(vmax_repeatless) #-2707.707, df=11
1-pchisq(9.444,3)
vmax_lengthless<-lmer(vmax~ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(vmax_model,vmax_lengthless) #2xLL=18.388, df=1, p<0.005
logLik(vmax_lengthless) #-2712.179, df=13
1-pchisq(18.388,1)

#### Model 3 - Average Distance ####
#most complex model - Average Distance
model0_distmean<-lmer(distmean~svl+ ROM*parity_mode +N_laid+ pregnancy_status*parity_mode + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE) #most complex model
summary(model0_distmean)


#pregnancy status*parity mode interaction
model1_distmean<-lmer(distmean~svl+ ROM*parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model0_distmean,model1_distmean) #0.1821 - non-significant, suggests removal of interaction
logLik(model0_distmean) #-3752.549, df=18
logLik(model1_distmean) #-3754.252, df=16
#drop parity mode x pregnancy status interaction

#ROM*parity_mode interaction
model2_distmean<-lmer(distmean~svl+ ROM+parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model1_distmean,model2_distmean) #0.6548 drop interaction
#Drop ROM x parity mode interaction

#tail length
model3_distmean<- lmer(distmean~svl+ ROM+parity_mode +N_laid+ pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model2_distmean,model3_distmean)
#p=8914 non-significant, drop tail length

#N_laid
model4_distmean<- lmer(distmean~svl+ ROM+parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model3_distmean,model4_distmean)
#p=0.6525, non-significant, drop N_laid

#svl
model5_distmean<-lmer(distmean~ ROM+parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmean, model5_distmean)#p<0.005, retain svl

#weight
model6_distmean<-lmer(distmean~svl+ ROM+parity_mode + pregnancy_status + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model6_distmean) #-3770.493, df=11
anova(model4_distmean,model6_distmean) #doesnt work
logLik(model4_distmean) #-3754.787, df=12
1-pchisq(31.412,1) #p<0.0005, retain weight

#repeat
model7_distmean<-lmer(distmean~svl+ ROM+parity_mode + pregnancy_status+ weight_end +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmean, model7_distmean) #p<0.005, retain repeat

#pregnancy status
model8_distmean<- lmer(distmean~svl+ROM+parity_mode + weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmean,model8_distmean) #p=0.8975 drop pregnancy status

#parity mode
model9_distmean<- lmer(distmean~svl+ROM + weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model8_distmean,model9_distmean) #p=0.6834 drop parity mode

#ROM
model10_distmean<- lmer(distmean~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model9_distmean,model10_distmean) #can't compare due to differences in dataset size being too large
logLik(model10_distmean) #-4603.245 (df=8)
logLik(model9_distmean)# -3755.176 (df=9)
anova(model10_distmean)
anova(model9_distmean) #ROM appears non-significant from anova table

#Final Model
distmean_model<-lmer(distmean~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
distmean_model<-lmer(distmean~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(distmean_model)
anova(distmean_model)


#### Model 4 - Maximum Distance ####

#most complex model - Average Distance
model0_distmax<-lmer(distmax~svl+ ROM*parity_mode +N_laid+ pregnancy_status*parity_mode + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE) #most complex model
summary(model0_distmax)

#pregnancy status*parity mode interaction
model1_distmax<-lmer(distmax~svl+ ROM*parity_mode +N_laid+ pregnancy_status + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model0_distmax,model1_distmax) #p=0.03606 - indicates significant, retain interaction
logLik(model0_distmax) #-3895.601, df=18
logLik(model1_distmax) #-3898.923 df=16
1-pchisq(3.322,2) #double check with 1-pchisq distribution - indicates not significant
#keep parity mode x pregnancy status interaction - but check later

#ROM*parity_mode interaction
model2_distmax<-lmer(distmax~svl+ ROM+parity_mode +N_laid+ pregnancy_status*parity_mode + tail_length+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model0_distmax,model2_distmax) #0.2789 drop interaction
#Drop ROM x parity mode interaction

#tail length
model3_distmax<- lmer(distmax~svl+ ROM+parity_mode +N_laid+ pregnancy_status*parity_mode+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model2_distmax,model3_distmax) #p=0.7837 non-significant, drop tail length

#N_laid
model4_distmax<- lmer(distmax~svl+ ROM+parity_mode + pregnancy_status*parity_mode+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model3_distmax,model4_distmax)
#p=0.7727, non-significant, drop N_laid

#svl
model5_distmax<-lmer(distmax~ ROM+ pregnancy_status*parity_mode+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmax, model5_distmax)#p<0.005, retain svl

#weight
model6_distmax<-lmer(distmax~svl+ ROM + pregnancy_status*parity_mode + repeat_m +(1|field_id), data=run_data, REML=FALSE)
logLik(model6_distmax) #-3908.552, df=13
anova(model4_distmax,model6_distmax) #doesn't work
logLik(model4_distmax) #-3896.957, df=14
1-pchisq(23.19,1) #p<0.0005, retain weight

#repeat
model7_distmax<-lmer(distmax~svl+ ROM+ pregnancy_status*parity_mode+ weight_end +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmax, model7_distmax) #p<0.005, retain repeat

#pregnancy status*parity mode interaction
model8_distmax<- lmer(distmax~svl+ROM+ parity_mode + pregnancy_status + weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmax,model8_distmax) #p=0.04583 keep pregnancy status * parity mode interaction
logLik(model4_distmax) #-3896.957, df=14
logLik(model8_distmax) #-3900.04, df=12
1-pchisq(3.083,2) #0.2140598, indicates lose interaction

#ROM
model9_distmax<- lmer(distmax~svl+ parity_mode*pregnancy_status+weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model4_distmax,model9_distmax) #can't compare due to differences in dataset size being too large
logLik(model4_distmax) #-3896.957 (df=14)
logLik(model9_distmax)#-4774.257 (df=13)
#can't compare with anova - select via non-significant terms
model4_distmax<- lmer(distmax~svl+ ROM+parity_mode + pregnancy_status*parity_mode+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
anova(model4_distmax) #indicates that interaction, parity mode, pregnancy status, ROM and weight should be removed
summary(model4_distmax)

#just svl, weight and repeat to test weight variable
model10_distmax<-lmer(distmax~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
model11_distmax<-lmer(distmax~svl+ repeat_m +(1|field_id), data=run_data, REML=FALSE)
anova(model10_distmax, model11_distmax) #can't compare
#trying logLik method
logLik(model10_distmax) #-4778.016 (df=8)
logLik(model11_distmax) #-4796.325 (df=7)
1-pchisq(18.309,1) #p<0.0001, therefore keep weight

#Final Model
distmax_model<-lmer(distmax~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
distmax_model<-lmer(distmax~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(distmax_model)
anova(distmax_model)


######################################## Final Models Used in Paper #################################################
#order of variables so that oviparous post parition is set to intercept
run_data$pregnancy_status <- factor(run_data$pregnancy_status, levels=c("laid", "pregnant"))
run_data$parity_mode<-factor(run_data$parity_mode, levels=c("oviparous","viviparous","hybrid"))

#svl and weight model
mod_svl <- lm(svl~weight_end, data = run_data)
summary(mod_svl)

#Weight model
mod_one_weight<-lmer(weight_end~parity_mode*pregnancy_status+ repeat_m +svl+(1|field_id), data=run_data)
summary(mod_one_weight) 
anova(mod_one_weight)

#emmeans pairwise differences between levels
summary(glht(mod_one_weight, linfct = mcp(parity_mode = "Tukey")), test = adjusted("holm"))
emmeans(mod_one_weight, list(pairwise ~ parity_mode*pregnancy_status), adjust = "tukey")
emmeans(mod_one_weight, list(pairwise ~ parity_mode|pregnancy_status), adjust = "tukey")

#ROM model
ROM_model<-lm(ROM~parity_mode, data=clean_ROM_data)
summary(ROM_model) #appears that there is a significant difference between ovi and viv for ROM
anova(ROM_model) #effect of parity mode on the ROM
display(ROM_model)
emmeans(ROM_model, list(pairwise ~ parity_mode), adjust = "tukey") #vivi seems to be significantly different from ovi and hybrid
plot(ROM_model)
shapiro.test(clean_ROM_data$ROM) #these are indicating that the variables are non-normally distributed
residuals_ROM <- residuals(ROM_model)
shapiro.test(residuals_ROM) #indicating non-normality of residuals
fitted_ROM <- fitted(ROM_model)
plot(fitted_ROM, residuals_ROM,
     xlab = "Fitted values", ylab = "Residuals",
     main = "Residuals vs Fitted Values")
abline(h = 0, col = "red")
qqnorm(residuals_lm, main = "Normal Q-Q Plot")
qqline(residuals_lm, col = "red")

# Log transformation of the response variable
clean_ROM_data$log_ROM <- log(clean_ROM_data$ROM)
ROM_model<-lm(log_ROM~parity_mode, data=clean_ROM_data)
summary(ROM_model) #appears that there is a significant difference between ovi and viv for ROM
anova(ROM_model) 
residuals_ROM <- residuals(ROM_model)
shapiro.test(residuals_ROM) #indicates normality of residuals
plot(ROM_model)
qqnorm(residuals_ROM, main = "Normal Q-Q Plot")
qqline(residuals_ROM, col = "red")
emmeans(ROM_model, list(pairwise ~ parity_mode), adjust = "tukey")


#Clutch Size model
CS_model <-lm(N_laid~parity_mode, data=clean_CS_data)
summary(CS_model)
anova(CS_model)
display(CS_model)
emmeans(CS_model, list(pairwise ~ parity_mode), adjust = "tukey")
plot(CS_model)
CS_residuals <- residuals(CS_model)
shapiro.test(CS_residuals) #indicating non-normal distribution
shapiro.test(clean_CS_data$N_laid) #indicating a non-normal distribution for this variable

# Log transformation of the response variable
clean_CS_data$log_CS <- log(clean_CS_data$N_laid)
CS_model<-lm(log_CS~parity_mode, data=clean_CS_data)
summary(CS_model) #appears that there is no significant difference between ovi and viv for ROM
anova(CS_model) 
residuals_CS <- residuals(CS_model)
shapiro.test(residuals_CS) #indicates non-normality of residuals
plot(CS_model)

#Poisson model for Clutch Size
CS2_mode1 <- glm(N_laid~1, family=poisson, data=clean_CS_data)
summary(CS2_mode1)
logLik(CS2_mode1) #-221.8907
CS2_model2 <- glm(N_laid~parity_mode, family=poisson, data=clean_CS_data)
summary(CS2_model2)
logLik(CS2_model2) #-219.8363
summary(CS2_model2)
1-pchisq(4.1088,2) #not significantly different from each other
#testing residual deviance
1-pchisq(55.571,99)
# Calculate Pearson residuals
pearson_resid <- residuals(CS2_model2, type = "pearson")
# Calculate the sum of squared Pearson residuals
sum_pearson_resid_sq <- sum(pearson_resid^2)
# Calculate the residual degrees of freedom
residual_df <- df.residual(CS2_model2)
# Calculate the dispersion statistic
dispersion_stat <- sum_pearson_resid_sq / residual_df
dispersion_stat #no evidence of overdispersion


#Final Average Speed Model
vmean_model<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
vmean_model<-lmer(vmean~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(vmean_model)
anova(vmean_model)

#Final Maximum Speed Model
vmax_model<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
vmax_model<-lmer(vmax~svl+ ROM*parity_mode + pregnancy_status+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(vmax_model)
anova(vmax_model)

#Final Average Distance Model
distmean_model<-lmer(distmean~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
distmean_model<-lmer(distmean~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(distmean_model)
anova(distmean_model)

#Final Maximum Distance Model
distmax_model<-lmer(distmax~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=FALSE)
distmax_model<-lmer(distmax~svl+ weight_end + repeat_m +(1|field_id), data=run_data, REML=TRUE)
summary(distmax_model)
anova(distmax_model)

#### Reproductive Stage (measured in days before birth/laying) on Lizard Mass ####
stage_data <- read.csv("lizard_running_data_modified_dates.csv", header = TRUE)
# making the repeat number a factor
stage_data$repeat_m<-as.factor(stage_data$repeat_m)
stage_data$parity_mode <- factor(stage_data$parity_mode, levels = c("oviparous", "hybrid", "viviparous"))
stage_data$pregnancy_status <- factor(stage_data$pregnancy_status, levels=c("pregnant", "laid"))

#test if Dates_diff has an effect on weight end
#subsetting just pregnant, as dates_diff is an indicator of gestational stage
pregnant <- subset(stage_data, pregnancy_status=="pregnant")

#Model of effect of date difference on weight
weight_date<-lmer(weight_end~parity_mode+Dates_diff+ repeat_m+ svl+(1|field_id), data=pregnant)
#mod_one_weight<-lmer(weight_end~parity_mode*Dates_diff+ repeat_m+ svl+(1|field_id), data=pregnant)
summary(weight_date) #significant effect of svl, parity mode oviparous vs. viviparous
anova(weight_date)
AICc(weight_date) #AICc is 401.66


ggplot(pregnant, aes(x = weight_end, y = Dates_diff, colour= field_id)) +
  geom_point() +
  geom_smooth(method = "lm", se = FALSE, color = "red") +
  labs(title = "Scatter Plot of Lizard Mass and Pregnancy Progress", x = "Mass of Lizard", y = "Pregnancy Progress")+
  theme(legend.position = "none")

ggplot(pregnant, aes(x = Dates_diff, y = weight_end)) +
  geom_line() +
  facet_wrap(~ field_id, scales = "free_y") +
  labs(x = "Dates_diff", y = "Weight", title = "Weight Change Over Dates_diff")

# Subset the data based on the category variable
category_subset <- "hybrid"  # Change this to the desired category
subset_df <- pregnant %>%
  filter(parity_mode == category_subset)

ggplot(subset_df, aes(x = weight_end, y = Dates_diff)) +
  geom_line() +
  facet_wrap(~ field_id, scales = "free_y") +
  labs(x = "weight", y = "dates_diff", title = "Weight Change Over Dates_diff for Hybrids")

########################################### Figures of the Paper ############################################

########################### First Figure of Paper - Combined Velocity and Weight Graph ##################################
#modifying the order of the levels for formatting the graphs
run_data$parity_mode <- factor(run_data$parity_mode, levels = c("oviparous", "hybrid", "viviparous"))
run_data$pregnancy_status <- factor(run_data$pregnancy_status, levels=c("pregnant", "laid"))

#Graph 1a: This graph has the weight of lizards for each parity mode, coloured by pregnancy status
weight_graph<-ggplot(data = run_data, aes(x=parity_mode, y=weight_end))+geom_boxplot(aes(colour=pregnancy_status))+
  labs(y="Mass of Lizard (g)", x="Parity Mode", col="Pregnancy Status")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(),
        legend.position = "none",
        axis.line = element_line(colour = "black"), 
        axis.title = element_text(size=12),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_y_continuous(breaks=seq(0,8, 1), expand=c(0,0), limits=c(0,NA))+
  scale_colour_discrete(labels=c("Pregnant","Post Parition"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  ylim(1,10)+
  geom_signif(y_position = c(7.3,8.75,9.75,10), xmin = c(0.8,1.81,2.81,0.8), 
              xmax = c(1.2,2.15,3.2,2.81), annotation = c("***","***","***","**"),
              tip_length = 0.01)

weight_graph

#adjusted weight
adj_weight_graph<-ggplot(data = run_data, aes(x=parity_mode, y=weight_adjusted))+geom_boxplot(aes(colour=pregnancy_status))+
  labs(y="Adjusted Mass of Lizard (g/cm)", x="Parity Mode", col="Pregnancy Status")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(),
        axis.line = element_line(colour = "black"), 
        axis.title = element_text(size=12),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_colour_discrete(labels=c("Pregnant","Post Parition"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))


adj_weight_graph


#Graph 1b: the average velocity for each parity mode, coloured by pregnancy status
velocity_graph<-ggplot(data = run_data, aes(x=parity_mode, y=vmean))+geom_boxplot(aes(colour=pregnancy_status))+
  labs(y="Average Speed of Lizard (cm/s)", x="Parity Mode", col="Pregnancy Status")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(), 
        axis.line = element_line(colour = "black"),
        axis.title = element_text(size=11),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_colour_discrete(labels=c("Pregnant","Post Parition"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  ylim(20,130)+
  geom_signif(y_position = c(120,120,120), xmin = c(0.8,1.81,2.81), 
              xmax = c(1.2,2.2,3.2), annotation = c("***","***","***"),
              tip_length = 0.01)

velocity_graph

#Graph 1c: the maximum velocity for each parity mode, coloured by pregnancy status
max_velocity_graph<-ggplot(data = run_data, aes(x=parity_mode, y=vmax))+geom_boxplot(aes(colour=pregnancy_status))+
  labs(y="Maximum Speed of Lizard (cm/s)", x="Parity Mode", col="Pregnancy Status")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(), 
        axis.line = element_line(colour = "black"),
        axis.title = element_text(size=11),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_colour_discrete(labels=c("Pregnant","Post Parition"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  ylim(40,150)+
  geom_signif(y_position = c(147,147,147), xmin = c(0.8,1.81,2.81), 
              xmax = c(1.18,2.2,3.2), annotation = c("***","***","***"),
              tip_length = 0.01)

max_velocity_graph

# Combining graphs with a common legend for both
#function to save the legend of a ggplot
legend<-get_legend(velocity_graph)
legend
leg<-as_ggplot(legend)

#Remove the legend from the velocity plots
velocity_graph <- velocity_graph + theme(legend.position="none")
max_velocity_graph <- max_velocity_graph + theme(legend.position="none")

velocity_graph
max_velocity_graph

#Arrange the weight and velocity graphs with a specific width
grid.arrange(weight_graph, velocity_graph, max_velocity_graph, leg, nrow=1, widths=c(2,2,2,1))

######################################### Second Figure of Paper - ROM and Model Predictions ###############################

#Figure 2a - ROM graph, showing the average ROM for each parity mode
# Define the desired order of the levels for parity_mode
parity_mode_order <- c('Oviparous', 'Hybrid', 'Viviparous')

# Reorder the levels of parity_mode
str(ROM_pregnant)
ROM_pregnant$parity_mode <- as.factor(ROM_pregnant$parity_mode)
ROM_pregnant$parity_mode <- factor(ROM_pregnant$parity_mode, levels = c('oviparous', 'hybrid','viviparous'))
# Check the levels of the parity_mode variable
levels(ROM_pregnant$parity_mode)

ROM_graph2<-ggplot(data = ROM_pregnant,
                   aes(x=parity_mode, y=ROM))+geom_boxplot(aes(colour=parity_mode))+
  labs(y="Average Relative Offspring Mass (g)", x="Parity Mode")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(),
        legend.position = "none",
        axis.line = element_line(colour = "black"), 
        axis.title = element_text(size=12),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  scale_color_manual(values=c("red", "dark blue", "dark green"))+
  geom_signif(y_position = c(0.7,0.6), xmin = c(1,2), 
              xmax = c(3,3), annotation = c("***","*"),
              tip_length = 0.01)


ROM_graph2

#Figure 2b - Plot of predicted effect of ROM on average velocity for each parity mode
#need to have model created - see below
#ggpredict plot for ROM and average speed
predicted_ROM_plot_vmean<- ggpredict(vmean_model, terms = c("ROM", "parity_mode"), type = "fe") %>%
  plot(show.title=FALSE) +
  labs(x = "Relative Offspring Mass (g)", y = "Average Speed (cm/s)", colour="Parity Mode") + 
  theme_minimal()

predicted_ROM_plot_vmean

#Figure 2c- ggpredict plot for ROM and maximum speed
predicted_ROM_plot_vmax<- ggpredict(vmax_model, terms = c("ROM", "parity_mode"), type = "fe") %>%
  plot(show.title=FALSE) +
  labs(x = "Relative Offspring Mass (g)", y = "Maximum Speed (cm/s)", colour="Parity Mode") + 
  theme_minimal()

predicted_ROM_plot_vmax

#Remove the legend from the velocity plots
predicted_ROM_plot_vmean <- predicted_ROM_plot_vmean + theme(legend.position="none")

#Combining the 3 graphs -ROM and weight with average and max velocity
grid.arrange(ROM_graph, predicted_ROM_plot_vmean, predicted_ROM_plot_vmax, ncol=3,widths=c(2.0, 2.0, 3.0))

####################################### Supplementary Figure Graphs ###########################################

#graph S1a: average distance graph for each parity mode, coloured by pregnancy status
distance_graph<-ggplot(data = run_data, aes(x=parity_mode, y=distmean, colour=pregnancy_status))+geom_boxplot()+
  labs(y="Average Distance Travelled by Lizard (mm)", x="Parity Mode", col="Pregnancy Status")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(), 
        axis.line = element_line(colour = "black"),
        axis.title = element_text(size=11),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_colour_discrete(labels=c("Pregnant","Post Parition"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  ylim(0,700)

distance_graph

#graph S1b: maximum distance travelled for each parity mode, coloured by pregnancy status
max_distance_graph<-ggplot(data = run_data, aes(x=parity_mode, y=distmax, colour=pregnancy_status))+geom_boxplot()+
  labs(y="Maximum Distance Travelled by Lizard (mm)", x="Parity Mode", col="Pregnancy Status")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(), 
        axis.line = element_line(colour = "black"),
        axis.title = element_text(size=11),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_colour_discrete(labels=c("Pregnant","Post Parition"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  ylim(0,700)

max_distance_graph

legend <- get_legend(max_distance_graph)
distance_graph <- distance_graph + theme(legend.position="none")
max_distance_graph <- max_distance_graph + theme(legend.position="none")

grid.arrange(distance_graph, max_distance_graph, legend, ncol=3, widths =c(2.5,2.5,1.0))


#Graph 1f: graph of clutch size (N_laid) of lizards for each parity mode
clutch_size_graph<-ggplot(data = ROM_pregnant, aes(x=parity_mode, y=N_laid, colour=parity_mode))+geom_boxplot()+
  labs(y="Clutch Size", x="Parity Mode")+
  theme(text=element_text(size=16), 
        panel.background = element_blank(),
        legend.position = "none",
        axis.line = element_line(colour = "black"), 
        axis.title = element_text(size=12),
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(size = 0.05, linetype = 'solid',colour = "black"), 
        panel.grid.minor.y = element_line(size = 0.05, linetype = 'solid',colour = "black"))+
  scale_x_discrete(labels = c('Oviparous','Hybrid','Viviparous'))+
  ylim(1,13)+
  scale_color_manual(values=c("red", "dark blue", "dark green"))

clutch_size_graph

